@@ -1,5 +1,5 @@
 #
-# $Id: Split.pm,v 0.31 2003/12/31 22:26:09 st.schubiger Exp $
+# $Id: Split.pm,v 0.32 2004/01/01 02:04:37 st.schubiger Exp $
 
 package Dir::Split;
 
@@ -13,40 +13,40 @@ use File::Path;
 use File::Spec;
 
 our (# external refs
-        $source_dir_ref, # scl
-        $target_dir_ref, # scl
+        $Source_dir_ref, # scl
+        $Target_dir_ref, # scl
 
      # opt refs
-        $mode_ref,     # scl
-        $override_ref, # scl
-        $warn_ref,     # scl
-        $verbose_ref,  # scl
-        $ident_ref,    # scl
-        $f_limit_ref,  # scl
-        $f_sort_ref,   # scl
-        $cont_num_ref, # scl
-        $sep_ref,      # scl
-        $l_req_ref,    # scl
-        $case_ref,     # scl
+        $Mode_ref,     # scl
+        $Override_ref, # scl
+        $Warn_ref,     # scl
+        $Verbose_ref,  # scl
+        $Ident_ref,    # scl
+        $F_limit_ref,  # scl
+        $F_sort_ref,   # scl
+        $Cont_num_ref, # scl
+        $Sep_ref,      # scl
+        $L_req_ref,    # scl
+        $Case_ref,     # scl
 
      # data refs
-        $files_ref,        # arr
-        $f_names_case_ref, # hsh
-        $f_names_char_ref, # hsh
-        $path_ref,         # scl
-        $ret_f_moved_ref,  # scl
-        $suffix_ref,       # scl
+        $Files_ref,        # arr
+        $F_names_case_ref, # hsh
+        $F_names_char_ref, # hsh
+        $Path_ref,         # scl
+        $Ret_f_moved_ref,  # scl
+        $Suffix_ref,       # scl
 
      # data
-        @files,
-        %f_names_case,
-        %f_names_char,
-        $path,
-        $ret_f_moved,
-        $suffix,
+        @Files,
+        %F_names_case,
+        %F_names_char,
+        $Path,
+        $Ret_f_moved,
+        $Suffix,
     );
 
-our $VERSION = 0.31;
+our $VERSION = 0.32;
 
 =head1 NAME
 
@@ -79,8 +79,8 @@ Dir::Split - Split the files of a directory to subdirectories.
  $dir = Dir::Split->new (\%behavior);
 
  # set source & target dir
- $source_dir = '/var/tmp/src';
- $target_dir = '/var/tmp/target';
+ $source_dir = '/tmp/src';
+ $target_dir = '/tmp/target';
 
  # split files to subdirs
  $files_moved = $dir->split (\$source_dir, \$target_dir);
@@ -212,11 +212,11 @@ integer - limit of files per subdirectory.
 
 =item C<sub_dir/file_sort>
 
-string - sorting order of files.
+string - sort order of files.
 
  MODES
-   +  ascending sort order
-   -  descending sort order
+   +  ascending
+   -  descending
 
 =item C<suffix/continue_num>
 
@@ -256,12 +256,12 @@ string - lower/upper case of the suffix.
 =cut
 
 sub new {
-    my ($pkg, $opt_ref) = @_;
+    my ($pkg, $Opt_ref) = @_;
     croak q~Invalid arguments: new (\%behavior)~
-      unless ref $opt_ref eq 'HASH';
+      unless ref $Opt_ref eq 'HASH';
 
     my $class = ref ($pkg) || $pkg;
-    my $obj = Dir::Split::_tie_var ($opt_ref);
+    my $obj = Dir::Split::_tie_var ($Opt_ref);
 
     bless $obj, $class;
 }
@@ -274,16 +274,16 @@ sub new {
 #
 
 sub _tie_var {
-    my $opt_ref = $_[0];
+    my $Opt_ref = $_[0];
 
     my %my_hash;
-    foreach my $key (keys %$opt_ref) {
-        if (ref $$opt_ref{$key} eq 'HASH') {
-            foreach ( keys %{$$opt_ref{$key}} ) {
-                $my_hash{$key}{$_} = $$opt_ref{$key}{$_};
+    foreach my $key (keys %$Opt_ref) {
+        if (ref $$Opt_ref{$key} eq 'HASH') {
+            foreach ( keys %{$$Opt_ref{$key}} ) {
+                $my_hash{$key}{$_} = $$Opt_ref{$key}{$_};
             }
         }
-        else { $my_hash{$key} = $$opt_ref{$key} }
+        else { $my_hash{$key} = $$Opt_ref{$key} }
     }
 
     return \%my_hash;
@@ -312,33 +312,33 @@ if none, it will return undef.
 
 sub split {
     my $self = shift;
-    ($source_dir_ref, $target_dir_ref) = @_;
+    ($Source_dir_ref, $Target_dir_ref) = @_;
     croak q~Invalid arguments: split (\$source_dir, \$target_dir)~
-      unless ref $source_dir_ref eq 'SCALAR' && ref $target_dir_ref eq 'SCALAR';
+      unless ref $Source_dir_ref eq 'SCALAR' && ref $Target_dir_ref eq 'SCALAR';
 
     # opts refs
-    $mode_ref = \$self->{'mode'};
-    $verbose_ref = \$self->{'options'}{'verbose'};
-    $override_ref = \$self->{'options'}{'override'};
-    $warn_ref = \$self->{'options'}{'warn'};
-    $ident_ref = \$self->{'sub_dir'}{'identifier'};
-    $f_limit_ref = \$self->{'sub_dir'}{'file_limit'};
-    $f_sort_ref = \$self->{'sub_dir'}{'file_sort'};
-    $cont_num_ref = \$self->{'suffix'}{'continue_num'};
-    $sep_ref = \$self->{'suffix'}{'separator'};
-    $l_req_ref = \$self->{'suffix'}{'length'};
-    $case_ref = \$self->{'suffix'}{'case'};
+    $Mode_ref = \$self->{'mode'};
+    $Verbose_ref = \$self->{'options'}{'verbose'};
+    $Override_ref = \$self->{'options'}{'override'};
+    $Warn_ref = \$self->{'options'}{'warn'};
+    $Ident_ref = \$self->{'sub_dir'}{'identifier'};
+    $F_limit_ref = \$self->{'sub_dir'}{'file_limit'};
+    $F_sort_ref = \$self->{'sub_dir'}{'file_sort'};
+    $Cont_num_ref = \$self->{'suffix'}{'continue_num'};
+    $Sep_ref = \$self->{'suffix'}{'separator'};
+    $L_req_ref = \$self->{'suffix'}{'length'};
+    $Case_ref = \$self->{'suffix'}{'case'};
 
     # data refs
-    $files_ref = \@files;
-    $f_names_case_ref = \%f_names_case;
-    $f_names_char_ref = \%f_names_char;
-    $path_ref = \$path;
-    $suffix_ref = \$suffix;
+    $Files_ref = \@Files;
+    $F_names_case_ref = \%F_names_case;
+    $F_names_char_ref = \%F_names_char;
+    $Path_ref = \$Path;
+    $Suffix_ref = \$Suffix;
 
     $self->_sanity_input;
     $self->_gather_files;
-    my $sub_suffix = "_suffix_$$mode_ref";
+    my $sub_suffix = "_suffix_$$Mode_ref";
     $self->$sub_suffix;
     $self->_move;
 }
@@ -351,50 +351,70 @@ sub split {
 #
 
 sub _sanity_input {
+    my %err_msg = ( source_dir => 'No source dir specified.',
+                    target_dir => 'No target dir specified.',
+                    mode       => 'No mode specified.',
+                    verbosity  => 'No verbosity specified.',
+                    warn       => 'No warn mode specified.',
+                    override   => 'No override mode specified.',
+                    ident      => 'No subdir identifier specified.',
+                    sep        => 'No suffix separator specified.',
+                    case       => 'No suffix case mode specified.',
+                    file_limit => 'No file limit specified.',
+                    file_sort  => 'No file sort mode specified.',
+                    cont_num   => 'No continuation mode specified.',
+                    length     => 'No suffix length specified.'
+    );
+
     no warnings;
-    my $err_str;
+    my $err_input;
     {
-        unless ($$mode_ref eq 'char' || $$mode_ref eq 'num') {
-            $err_str = 'No mode specified.'; last;
+        unless ($$Source_dir_ref) {
+            $err_input = $err_msg{'source_dir'}; last;
         }
-        unless ($$verbose_ref =~ /^0|1$/) {
-            $err_str = 'No verbosity specified.'; last;
+        unless ($$Target_dir_ref) {
+            $err_input = $err_msg{'target_dir'}; last;
         }
-        unless ($$warn_ref =~ /^none|files|dirs|all$/) {
-            $err_str = 'No warn mode specified.'; last;
+        unless ($$Mode_ref eq 'char' || $$Mode_ref eq 'num') {
+            $err_input = $err_msg{'mode'}; last;
         }
-        unless ($$override_ref =~ /^none|files|dirs|all$/) {
-            $err_str = 'No override mode specified.'; last;
+        unless ($$Verbose_ref =~ /^0|1$/) {
+            $err_input = $err_msg{'verbosity'}; last;
         }
-        unless ($$ident_ref =~ /\w/) {
-            $err_str = 'No subdir identifier specified.'; last;
+        unless ($$Warn_ref =~ /^none|files|dirs|all$/) {
+            $err_input = $err_msg{'warn'}; last;
         }
-        unless ($$sep_ref) {
-            $err_str = 'No suffix separator specified.'; last;
+        unless ($$Override_ref =~ /^none|files|dirs|all$/) {
+            $err_input = $err_msg{'override'}; last;
         }
-        if ($$mode_ref eq 'char') {
-            unless ($$case_ref eq 'lower' || $$case_ref eq 'upper') {
-                $err_str = 'No suffix case mode specified.'; last;
+        unless ($$Ident_ref =~ /\w/) {
+            $err_input = $err_msg{'ident'}; last;
+        }
+        unless ($$Sep_ref) {
+            $err_input = $err_msg{'sep'}; last;
+        }
+        if ($$Mode_ref eq 'char') {
+            unless ($$Case_ref eq 'lower' || $$Case_ref eq 'upper') {
+                $err_input = $err_msg{'case'}; last;
             }
         }
-        elsif ($$mode_ref eq 'num') {
-            unless ($$f_limit_ref =~ /\d/) {
-                $err_str = 'No file limit specified.'; last;
+        elsif ($$Mode_ref eq 'num') {
+            unless ($$F_limit_ref =~ /\d/) {
+                $err_input = $err_msg{'file_limit'}; last;
             }
-            unless ($$f_sort_ref eq '+' || $$f_sort_ref eq '-') {
-                $err_str = 'No file sort mode specified.'; last;
+            unless ($$F_sort_ref eq '+' || $$F_sort_ref eq '-') {
+                $err_input = $err_msg{'file_sort'}; last;
             }
-            unless ($$cont_num_ref eq 'y' || $$cont_num_ref eq 'n') {
-                $err_str = 'No continuation mode specified.'; last;
+            unless ($$Cont_num_ref eq 'y' || $$Cont_num_ref eq 'n') {
+                $err_input = $err_msg{'cont_num'}; last;
             }
-            unless ($$l_req_ref =~ /\d/) {
-                $err_str = 'No suffix length specified.'; last;
+            unless ($$L_req_ref =~ /\d/) {
+                $err_input = $err_msg{'length'}; last;
             }
 
         }
     }
-    croak $err_str if $err_str;
-    use warnings;
+    croak $err_input if $err_input;
 }
 
 #
@@ -407,16 +427,16 @@ sub _sanity_input {
 sub _gather_files {
     my $self = $_[0];
 
-    $self->_dir_read ($source_dir_ref, $files_ref);
-    @$files_ref = grep !-d File::Spec->catfile($$source_dir_ref, $_), @$files_ref;
+    $self->_dir_read ($Source_dir_ref, $Files_ref);
+    @$Files_ref = grep !-d File::Spec->catfile($$Source_dir_ref, $_), @$Files_ref;
 
-    if ($$mode_ref eq 'num' && ($$f_sort_ref eq '+' || $$f_sort_ref eq '-') ) {
+    if ($$Mode_ref eq 'num' && ($$F_sort_ref eq '+' || $$F_sort_ref eq '-') ) {
         # preserve case-sensitive filenames in hash.
-        foreach (@$files_ref) { $$f_names_case_ref{lc($_)} = $_ }
-        @$files_ref = map { lc } @$files_ref;
+        foreach (@$Files_ref) { $$F_names_case_ref{lc($_)} = $_ }
+        @$Files_ref = map { lc } @$Files_ref;
 
-        if ($$f_sort_ref eq '+') { @$files_ref = sort @$files_ref }
-        elsif ($$f_sort_ref eq '-') { @$files_ref = reverse @$files_ref }
+        if ($$F_sort_ref eq '+') { @$Files_ref = sort @$Files_ref }
+        elsif ($$F_sort_ref eq '-') { @$Files_ref = reverse @$Files_ref }
     }
 }
 
@@ -429,15 +449,15 @@ sub _gather_files {
 #
 
 sub _suffix_char {
-    foreach my $file (@$files_ref) {
+    foreach my $file (@$Files_ref) {
         ($_) = $file =~ /^(.)/;
         if ($_ =~ /\w/) {
-            if ($$case_ref eq 'upper') { $_ = uc ($_) }
-            elsif ($$case_ref eq 'lower') { $_ = lc ($_) }
+            if ($$Case_ref eq 'upper') { $_ = uc ($_) }
+            elsif ($$Case_ref eq 'lower') { $_ = lc ($_) }
         }
-        push (@{$$f_names_char_ref{$_}}, $file);
+        push (@{$$F_names_char_ref{$_}}, $file);
     }
-    undef @$files_ref;
+    undef @$Files_ref;
 }
 
 #
@@ -453,28 +473,29 @@ sub _suffix_num {
     my $self = $_[0];
 
     # surpress warnings
-    $$suffix_ref = 0;
+    $$Suffix_ref = 0;
 
-    if ($$cont_num_ref eq 'y') {
+    if ($$Cont_num_ref eq 'y') {
         my @dirs;
-        $self->_dir_read ($target_dir_ref, \@dirs);
-        @dirs = grep -d File::Spec->catfile($$target_dir_ref, $_), @dirs;
+        $self->_dir_read ($Target_dir_ref, \@dirs);
+        @dirs = grep -d File::Spec->catfile($$Target_dir_ref, $_), @dirs;
 
-        my $sep = quotemeta $$sep_ref;
+        my $sep = quotemeta $$Sep_ref;
         foreach (@dirs) {
             # extract exist. identifier
             ($_) = /(.+?)$sep(.*)/;
-            next unless $$ident_ref eq $_;
+            next unless $$Ident_ref eq $_;
             # increase suffix to highest number
-            $$suffix_ref = $2 if $2 > $$suffix_ref;
+            $$Suffix_ref = $2 if $2 > $$Suffix_ref;
         }
-        # avoid collisions with exist. subdirs
-        $$suffix_ref++;
     }
 
-    if (length $$suffix_ref != $$l_req_ref) {
-        my $format = "%0.$$l_req_ref" . 'd';
-        $$suffix_ref = sprintf $format, $$suffix_ref;
+    # Initialize suffix or avoid suffix collision if != 0
+    $$Suffix_ref++;
+
+    if (length $$Suffix_ref != $$L_req_ref) {
+        my $format = "%0.$$L_req_ref" . 'd';
+        $$Suffix_ref = sprintf $format, $$Suffix_ref;
     }
 }
 
@@ -488,12 +509,13 @@ sub _suffix_num {
 sub _move {
     my $self = $_[0];
 
-    $ret_f_moved_ref = \$ret_f_moved;
+    $Ret_f_moved_ref = \$Ret_f_moved;
 
-    my $sub_move = "_move_$$mode_ref";
+    # sub handler
+    my $sub_move = "_move_$$Mode_ref";
     $self->$sub_move;
 
-    return $$ret_f_moved_ref ? $$ret_f_moved_ref : undef;
+    return $$Ret_f_moved_ref ? $$Ret_f_moved_ref : undef;
 }
 
 #
@@ -505,12 +527,12 @@ sub _move {
 sub _move_num {
     my $self = $_[0];
 
-    for (; @$files_ref; $$suffix_ref++) {
-       $self->_mkpath ($$suffix_ref);
+    for (; @$Files_ref; $$Suffix_ref++) {
+       $self->_mkpath ($$Suffix_ref);
 
-        for (my $i = 0; $i < $$f_limit_ref; $i++) {
-            last unless my $file = shift @$files_ref;
-            $self->_cp_unlink ($$f_names_case_ref{$file});
+        for (my $i = 0; $i < $$F_limit_ref; $i++) {
+            last unless my $file = shift @$Files_ref;
+            $self->_cp_unlink ($$F_names_case_ref{$file});
         }
     }
 }
@@ -526,11 +548,11 @@ sub _move_num {
 sub _move_char {
     my $self = $_[0];
 
-    foreach (sort keys %$f_names_char_ref) {
+    foreach (sort keys %$F_names_char_ref) {
         $self->_mkpath ($_);
 
-        while (@{$$f_names_char_ref{$_}}) {
-            $self->_cp_unlink (shift @{$$f_names_char_ref{$_}});
+        while (@{$$F_names_char_ref{$_}}) {
+            $self->_cp_unlink (shift @{$$F_names_char_ref{$_}});
         }
     }
 }
@@ -552,47 +574,47 @@ sub _dir_read {
 }
 
 #
-# _mkpath ($suffix)
+# _mkpath ($Suffix)
 #
 # Creates subdirs.
-# Optional warning and overriding avoidance
-# upon dir collision.
+# Upon dir collision optional warning
+# and overriding avoidance.
 #
 
 sub _mkpath {
-    shift; my $suffix = $_[0];
+    shift; my $Suffix = $_[0];
 
-    $$path_ref = File::Spec->catfile($$target_dir_ref, "$$ident_ref$$sep_ref$suffix");
+    $$Path_ref = File::Spec->catfile($$Target_dir_ref, "$$Ident_ref$$Sep_ref$Suffix");
 
-    if (-e $$path_ref) {
-        warn "$$path_ref exists.\n" if $$warn_ref eq 'all' || $$warn_ref eq 'dirs';
-        return unless $$override_ref eq 'all' || $$override_ref eq 'dirs';
+    if (-e $$Path_ref) {
+        warn "$$Path_ref exists.\n" if $$Warn_ref eq 'all' || $$Warn_ref eq 'dirs';
+        return unless $$Override_ref eq 'all' || $$Override_ref eq 'dirs';
     }
-    mkpath $$path_ref, $$verbose_ref or croak qq~Could not create subdir $$path_ref: $!~;
+    mkpath $$Path_ref, $$Verbose_ref or croak qq~Could not create subdir $$Path_ref: $!~;
 }
 
 #
 # _cp_unlink ($file)
 #
 # Copies files and unlinks them after they've been copied.
-# Optional warning and overriding avoidance upon file collision.
+# Upon file collision optional warning and overriding avoidance.
 #
 
 sub _cp_unlink {
     shift; my $file = $_[0];
 
-    my $path_full = File::Spec->catfile($$path_ref, $file);
-    $file = File::Spec->catfile($$source_dir_ref, $file);
+    my $path_full = File::Spec->catfile($$Path_ref, $file);
+    $file = File::Spec->catfile($$Source_dir_ref, $file);
 
     if (-e $path_full) {
-        warn "$path_full exists.\n" if $$warn_ref eq 'all' || $$warn_ref eq 'files';
-        return unless $$override_ref eq 'all' || $$override_ref eq 'files';
+        warn "$path_full exists.\n" if $$Warn_ref eq 'all' || $$Warn_ref eq 'files';
+        return unless $$Override_ref eq 'all' || $$Override_ref eq 'files';
     }
     cp ($file, $path_full) or
       croak qq~Could not copy file $file to subdir $path_full: $!~;
     unlink ($file) or croak qq~Could not remove file $file: $!~;
 
-    $$ret_f_moved_ref++;
+    $$Ret_f_moved_ref++;
 }
 
 1;
@@ -601,7 +623,7 @@ __END__
 
 =head1 EXAMPLES
 
-Assuming the source directory I</var/tmp/src> contains 5 files:
+Assuming the source directory I</tmp/src> contains 5 files:
 
     +- _12.tmp
     +- abc.tmp
@@ -609,7 +631,7 @@ Assuming the source directory I</var/tmp/src> contains 5 files:
     +- ghi.tmp
     +- jkl.tmp
 
-After splitting the directory tree in the target directory I</var/tmp/target> 
+After splitting the directory tree in the target directory I</tmp/target>
 will look as following:
 
 =head2 numeric splitting
@@ -660,4 +682,4 @@ This program is free software; you may redistribute it and/or modify it under th
 
 Steven Schubiger
 
-=cut
\ No newline at end of file
+=cut
